function m = tchmean(v)
%
% tchmean - compute mean of a vector
% On input:
%     v: vector of n elements
% On output:
%     m: mean value of v
% Call:
%     m = tchmean(v)
%

n = length(v);
m = sum(v)/n;
